##  Collect Data from Fact Sheet Owners
Effective data collection is crucial for informed decision-making. However, the challenge lies in managing the vast amount of data and ensuring its accuracy and relevance over time. Assigning responsibility and accountability to the contributors is the key.
Once you have the initial data in your workspace, the next step is to set the responsibilities to users regarding a Fact Sheet by assigning Subscription Roles. It is a mechanism to ensure subscribers of Fact Sheets are notified and have a clear call-to-action to maintain and administer the Fact Sheet data.
When defining a Subscription Role, you specify the Subscription Type for that role. Subscription Type determines the responsibilities of a Subscription Role with respect to Fact Sheets. Subscription Type can be one of the following types:
  * Responsible: This Subscription type is in charge of keeping the Fact Sheet up to date and correct.
  * Accountable: Subscription roles of this type carry overall accountability and often handle business responsibilities associated with Fact Sheets.
  * Observer: Subscription roles of this type are notified and kept up-to-date .
  * All: When defining a Subscription role, you can choose all the above types for increased flexibility.


Once defined, you can assign users, or users themselves can subscribe to Fact Sheets based on the defined Subscription roles and types.
To learn more, see [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
YesNo
Send
